==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_external/l10n/zh_TW.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "請求失敗，請驗證您的應用程式金鑰及密碼是否正確",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "存取失敗，請驗證您的應用程式金鑰及密碼是否正確",
    "Please provide a valid app key and secret." : "請提供有效的應用程式金鑰及密碼",
    "Step 1 failed. Exception: %s" : "步驟 1 失敗，出現異常: %s",
    "Step 2 failed. Exception: %s" : "步驟 2 失敗，出現異常: %s",
    "External storage" : "外部儲存",
    "Dropbox App Configuration" : "Dropbox 應用設置",
    "Google Drive App Configuration" : "Google Drive 應用設置",
    "Personal" : "個人",
    "System" : "系統",
    "Grant access" : "允許存取",
    "Error configuring OAuth1" : "設定 OAuth1 時發生錯誤",
    "Error configuring OAuth2" : "設定 OAuth2 時發生錯誤",
    "Generate keys" : "產生金鑰",
    "Error generating key pair" : "產生金鑰對錯誤",
    "All users. Type to select user or group." : "所有人都可以使用，或者選擇特定使用者、群組",
    "(group)" : "(群組)",
    "Saved" : "已儲存",
    "Saving..." : "儲存中...",
    "Save" : "儲存",
    "Empty response from the server" : "服務器没有回應",
    "Couldn't access. Please logout and login to activate this mount point" : "無法存取。請重新登出再登入啟動此掛載點。",
    "Couldn't get the information from the remote server: {code} {type}" : "無法從遠程伺服器上獲取資料 : {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "無法得到外部掛載點的列表: {type}",
    "There was an error with message: " : "錯誤信息:",
    "External mount error" : "外部掛載錯誤",
    "external-storage" : "外部儲存",
    "Username" : "使用者名稱",
    "Password" : "密碼",
    "Storage with id \"%i\" not found" : "沒有找到編號 \"%i\" 的儲存空間 ",
    "Invalid backend or authentication mechanism class" : "無效的後端處理或是驗證方式",
    "Invalid mount point" : "無效的掛載點",
    "Objectstore forbidden" : "物件儲存禁止存取",
    "Invalid storage backend \"%s\"" : "無效的後端儲存 \"%s\"",
    "Not permitted to use backend \"%s\"" : "不被允許使用後端儲存 \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "不被允許使用驗證機制 \"%s\"",
    "Unsatisfied backend parameters" : "無法滿足後端所需的參數條件",
    "Unsatisfied authentication mechanism parameters" : "無法滿足驗證機制所需的參數條件",
    "Insufficient data: %s" : "資料不足: %s",
    "%s" : "%s",
    "Access key" : "存取金鑰",
    "Secret key" : "私密金鑰",
    "None" : "無",
    "App key" : "App 金鑰",
    "App secret" : "App 密碼",
    "Client ID" : "客戶端ID",
    "Client secret" : "客戶端密碼",
    "OpenStack" : "OpenStack",
    "Tenant name" : "租戶/專案名稱",
    "Identity endpoint URL" : "身份識別終端點 URL",
    "Rackspace" : "Rackspace",
    "API key" : "API金鑰",
    "Username and password" : "使用者帳號和密碼",
    "RSA public key" : "RSA 公開金鑰",
    "Public key" : "公開金鑰",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "主機名稱",
    "Port" : "連接埠",
    "Region" : "地區",
    "Enable SSL" : "啟用 SSL",
    "Enable Path Style" : "啟用路徑格式",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "遠端子資料夾",
    "Secure https://" : "安全 https://",
    "Dropbox" : "Dropbox",
    "FTP" : "檔案傳輸協定-FTP",
    "Host" : "主機",
    "Secure ftps://" : "安全 ftps://",
    "Google Drive" : "Google 雲端硬碟",
    "Local" : "本地",
    "Location" : "地點",
    "SFTP" : "安全檔案傳輸協定-SFTP",
    "SFTP with secret key login" : "以密碼金鑰登入SFTP",
    "SMB / CIFS" : "伺服器訊息區塊-SMB/網路文件共享系統 (CIFS)",
    "Share" : "分享",
    "Domain" : "網域名稱",
    "SMB / CIFS using OC login" : "SMB / CIFS 使用 OC 登入",
    "Username as share" : "以使用者名稱分享",
    "OpenStack Object Storage" : "OpenStack 物件儲存",
    "Service name" : "服務名稱",
    "Request timeout (seconds)" : "請求超時 (秒)",
    "External storages" : "外部儲存",
    "No external storage configured" : "目前尚未配置任何外部儲存",
    "You can add external storages in the personal settings" : "在個人設定裡您可以自行加入外部儲存設定",
    "Name" : "名稱",
    "Storage type" : "儲存類型",
    "Scope" : "範圍",
    "Enable encryption" : "啟用加密",
    "Enable previews" : "啟動預覽",
    "Enable sharing" : "啟動分享",
    "Check for changes" : "檢查變動",
    "Never" : "絕不",
    "Folder name" : "資料夾名稱",
    "Authentication" : "驗證",
    "Configuration" : "設定",
    "Available for" : "可用的",
    "Add storage" : "增加儲存區",
    "Advanced settings" : "進階設定",
    "Delete" : "刪除",
    "Allow users to mount external storage" : "允許使用者能自行掛載外部儲存",
    "Allow users to mount the following external storage" : "允許使用者自行掛載以下的外部儲存",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "無法從ownCloud伺服器得到資訊: {code} {type}",
    "ownCloud" : "ownCloud",
    "<b>Note:</b> " : "<b>警告:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>警告:</b> PHP 並未啓用 Curl 的支援，因此無法掛載 %s 。請洽您的系統管理員將其安裝並啓用。",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>警告</b>：PHP 並未啓用 FTP 的支援，因此無法掛載 %s，請洽您的系統管理員將其安裝並啓用。",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>警告</b>並未安裝 \"%s\"，因此無法掛載 %s。請洽您的系統管理員將其安裝並啓用。",
    "External Storage" : "外部儲存"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/files_external/l10n/zh_TW.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "外部儲存",
    "Personal" : "個人",
    "System" : "系統",
    "Grant access" : "允許存取",
    "Error configuring OAuth1" : "設定 OAuth1 時發生錯誤",
    "Please provide a valid app key and secret." : "請提供有效的應用程式金鑰及密碼",
    "Error configuring OAuth2" : "設定 OAuth2 時發生錯誤",
    "Generate keys" : "產生金鑰",
    "Error generating key pair" : "產生金鑰對錯誤",
    "All users. Type to select user or group." : "所有人都可以使用，或者選擇特定使用者、群組",
    "(group)" : "(群組)",
    "Compatibility with Mac NFD encoding (slow)" : "與Mac的NFD編碼格式相容(較慢)",
    "Admin defined" : "管理者定義",
    "Are you sure you want to delete this external storage" : "您確定要刪除額外的空間？",
    "Delete storage?" : "刪除空間",
    "Saved" : "已儲存",
    "Saving..." : "儲存中...",
    "Save" : "儲存",
    "Empty response from the server" : "服務器没有回應",
    "Couldn't access. Please log out and in again to activate this mount point" : "無法存取，請登出後重新登入來啟用這個掛載點。",
    "Couldn't get the information from the remote server: {code} {type}" : "無法從遠程伺服器上獲取資料 : {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "無法得到外部掛載點的列表: {type}",
    "There was an error with message: " : "錯誤信息:",
    "External mount error" : "外部掛載錯誤",
    "external-storage" : "外部儲存",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "無法取得Windows網路磁碟掛載點清單：伺服器無回應。",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "有些外部掛載位置設定無法連線，請點(多個)紅色橫幅了解詳情。",
    "Please enter the credentials for the {mount} mount" : "請輸入認證來進行掛載{掛載來源}",
    "Username" : "使用者名稱",
    "Password" : "密碼",
    "Credentials saved" : "已儲存憑證",
    "Credentials saving failed" : "憑證儲存失敗",
    "Credentials required" : "需要憑證訊息",
    "Storage with ID \"%d\" not found" : "沒有找到使用者 \"%d\" 的儲存空間 ",
    "Invalid backend or authentication mechanism class" : "無效的後端處理或是驗證方式",
    "Invalid mount point" : "無效的掛載點",
    "Objectstore forbidden" : "物件儲存禁止存取",
    "Invalid storage backend \"%s\"" : "無效的後端儲存 \"%s\"",
    "Not permitted to use backend \"%s\"" : "不被允許使用後端儲存 \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "不被允許使用驗證機制 \"%s\"",
    "Unsatisfied backend parameters" : "無法滿足後端所需的參數條件",
    "Unsatisfied authentication mechanism parameters" : "無法滿足驗證機制所需的參數條件",
    "Insufficient data: %s" : "資料不足: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "使用者\"%d\"無法對此儲存位置進行編輯",
    "Access key" : "存取金鑰",
    "Secret key" : "私密金鑰",
    "Builtin" : "公告",
    "None" : "無",
    "OAuth1" : "OAuth1",
    "App key" : "App 金鑰",
    "App secret" : "App 密碼",
    "OAuth2" : "OAuth2",
    "Client ID" : "客戶端ID",
    "Client secret" : "客戶端密碼",
    "OpenStack" : "OpenStack",
    "Tenant name" : "租戶/專案名稱",
    "Identity endpoint URL" : "身份識別終端點 URL",
    "Rackspace" : "Rackspace",
    "API key" : "API金鑰",
    "Username and password" : "使用者帳號和密碼",
    "RSA public key" : "RSA 公開金鑰",
    "Public key" : "公開金鑰",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "主機名稱",
    "Port" : "連接埠",
    "Region" : "地區",
    "Enable SSL" : "啟用 SSL",
    "Enable Path Style" : "啟用路徑格式",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "遠端子資料夾",
    "Secure https://" : "安全 https://",
    "FTP" : "檔案傳輸協定-FTP",
    "Host" : "主機",
    "Secure ftps://" : "安全 ftps://",
    "Local" : "本地",
    "Location" : "地點",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "安全檔案傳輸協定-SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "以密碼金鑰登入SFTP",
    "SMB / CIFS" : "伺服器訊息區塊-SMB/網路文件共享系統 (CIFS)",
    "Share" : "分享",
    "Domain" : "網域名稱",
    "SMB / CIFS using OC login" : "SMB / CIFS 使用 OC 登入",
    "Username as share" : "以使用者名稱分享",
    "OpenStack Object Storage" : "OpenStack 物件儲存",
    "Service name" : "服務名稱",
    "Request timeout (seconds)" : "請求超時 (秒)",
    "No external storage configured" : "目前尚未配置任何外部儲存",
    "You can add external storages in the personal settings" : "在個人設定裡您可以自行加入外部儲存設定",
    "Name" : "名稱",
    "Storage type" : "儲存類型",
    "Scope" : "範圍",
    "Enable encryption" : "啟用加密",
    "Enable previews" : "啟動預覽",
    "Enable sharing" : "啟動分享",
    "Check for changes" : "檢查變動",
    "Never" : "絕不",
    "Once every direct access" : "在每次進行存取動作時",
    "Folder name" : "資料夾名稱",
    "External storage" : "外部儲存",
    "Authentication" : "驗證",
    "Configuration" : "設定",
    "Available for" : "可用的",
    "Add storage" : "增加儲存區",
    "Advanced settings" : "進階設定",
    "Delete" : "刪除",
    "Allow users to mount external storage" : "允許使用者能自行掛載外部儲存",
    "Allow users to mount the following external storage" : "允許使用者自行掛載以下的外部儲存",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "請求失敗，請驗證您的應用程式金鑰及密碼是否正確",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "存取失敗，請驗證您的應用程式金鑰及密碼是否正確",
    "Step 1 failed. Exception: %s" : "步驟 1 失敗，出現異常: %s",
    "Step 2 failed. Exception: %s" : "步驟 2 失敗，出現異常: %s",
    "Dropbox App Configuration" : "Dropbox 應用設置",
    "Google Drive App Configuration" : "Google Drive 應用設置",
    "Storage with id \"%i\" not found" : "沒有找到編號 \"%i\" 的儲存空間 ",
    "Storage with id \"%i\" is not user editable" : "使用者\"%i\"無法對此儲存位置進行編輯",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google 雲端硬碟"
},
"nplurals=1; plural=0;");
